@@ -823,9 +823,9 @@ struct samplv1_glide
 
 		if (m_frames > 0) {
 			m_freq = m_last;
-			m_step = (m_last - freq) / float(m_frames);
+			m_step = (m_freq - freq) / float(m_frames);
 		} else {
-			m_freq = freq;
+			m_freq = 0.0f;
 			m_step = 0.0f;
 		}
 
@@ -1238,8 +1238,8 @@ samplv1_voice::samplv1_voice ( samplv1_impl *pImpl ) :
 	dcf17(&pImpl->dcf1_formant),
 	dcf18(&pImpl->dcf1_formant),
 	gen1_glide(pImpl->gen1_last),
-	out1_volume(1.0f),
 	out1_panning(0.0f),
+	out1_volume(1.0f),
 	sustain(false)
 {
 }
